pub enum MdbxError {
Show 38 variants
KeyExist,
NotFound,
NoData,
PageNotFound,
Corrupted,
Panic,
VersionMismatch,
Invalid,
MapFull,
DbsFull,
ReadersFull,
TxnFull,
CursorFull,
PageFull,
UnableExtendMapSize,
Incompatible,
BadRslot,
BadTxn,
BadValSize,
BadDbi,
Problem,
Busy,
Multival,
BadSignature,
WannaRecovery,
KeyMismatch,
DecodeError,
Access,
TooLarge,
DecodeErrorLenDiff,
NestedTransactionsUnsupportedWithWriteMap,
WriteTransactionUnsupportedInReadOnlyMode,
ReadTransactionTimeout,
BotchedTransaction,
Permission,
Other(i32),
RequiresDupSort,
RequiresDupFixed,
}Expand description
An MDBX error kind.
This represents various error conditions that can occur when interacting with the MDBX database.
Variants
KeyExist
Key/data pair already exists.
NotFound
No matching key/data pair found.
NoData
The cursor is already at the end of data.
PageNotFound
Requested page not found.
Corrupted
Database is corrupted.
Panic
Fatal environment error.
VersionMismatch
DB version mismatch.
Invalid
File is not an MDBX file.
MapFull
Environment map size limit reached.
DbsFull
Too many DBI-handles (maxdbs reached).
ReadersFull
Too many readers (maxreaders reached).
TxnFull
Transaction has too many dirty pages (i.e., the transaction is too big).
CursorFull
Cursor stack limit reached.
PageFull
Page has no more space.
UnableExtendMapSize
The database engine was unable to extend mapping, e.g. the address space is unavailable or busy.
This can mean:
- The database size was extended by other processes beyond the environment map size, and the engine was unable to extend the mapping while starting a read transaction. The environment should be re-opened to continue.
- The engine was unable to extend the mapping during a write transaction or an explicit call to change the geometry of the environment.
Incompatible
Environment or database is not compatible with the requested operation or flags.
BadRslot
Invalid reuse of reader locktable slot.
BadTxn
Transaction is not valid for requested operation.
BadValSize
Invalid size or alignment of key or data for the target database.
BadDbi
The specified DBI-handle is invalid.
Problem
Unexpected internal error.
Busy
Another write transaction is running.
Multival
The specified key has more than one associated value.
BadSignature
Wrong signature of a runtime object(s).
WannaRecovery
Database should be recovered, but cannot be done automatically since it’s in read-only mode.
KeyMismatch
The given key value is mismatched to the current cursor position.
DecodeError
Decode error: An invalid parameter was specified.
Access
The environment opened in read-only.
TooLarge
Database is too large for the current system.
DecodeErrorLenDiff
Decode error length difference:
An invalid parameter was specified, or the environment has an active write transaction.
NestedTransactionsUnsupportedWithWriteMap
If the Environment was opened with
EnvironmentKind::WriteMap flag,
nested transactions are not supported.
WriteTransactionUnsupportedInReadOnlyMode
If the Environment was opened with in read-only
mode Mode::ReadOnly, write
transactions can’t be opened.
ReadTransactionTimeout
Read transaction has been timed out.
BotchedTransaction
The transaction commit was aborted due to previous errors.
This can happen in exceptionally rare cases and it signals the problem coming from inside of mdbx.
Permission
Permission defined
Other(i32)
Unknown error code.
RequiresDupSort
Operation requires DUP_SORT flag on database.
RequiresDupFixed
Operation requires DUP_FIXED flag on database.